#
# spec file for package sparkleshare
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         with_translations 0

Name:           sparkleshare
Version:        1.4
Release:        3.2
Summary:        A file sharing and collaboration tool
License:        GPL-3.0+
Group:          Productivity/Archiving/Backup
Url:            http://sparkleshare.org
Source:         https://github.com/hbons/SparkleShare/archive/%{version}.tar.gz
BuildRequires:  fdupes
%if %{with_translations}
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
%endif
BuildRequires:  libtool
BuildRequires:  mono-devel
BuildRequires:  nant
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-sharp-2.0) >= 2.12.2
BuildRequires:  pkgconfig(gtk-sharp-3.0) >= 2.99.1
BuildRequires:  pkgconfig(notify-sharp-3.0)
BuildRequires:  pkgconfig(webkitgtk-sharp-3.0)
Requires:       git-core >= 1.7.1
Requires:       gvfs
Requires:       mono-core
Requires:       openssh
Obsoletes:      nautilus-sparkleshare < %{version}
Recommends:     %{name}-lang
%if ! %{with_translations}
Obsoletes:      %{name}-lang < %{version}
Provides:       %{name}-lang = %{version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SparkleShare is a file sharing and collaboration tool inspired by Dropbox.

SparkleShare isn't just a piece of software, it's part of your workflow.
It's designed to make sharing documents and collaboration easier,
and to make peers aware of what you are doing. It allows you to instantly
sync with any Git repository you have access to. The user interface and
features are made to support this goal.

Though SparkleShare is not made to be a graphical frontend for git or a
backup tool, it may be useful for other kinds of purposes as well, like
backing up small files or monitoring your favourite project.

%if with_translations
%lang_package
%endif
%prep
%setup -q -n SparkleShare-%{version}
sed -i "s/4\\.0/4.5/g" build/m4/shamrock/mono.m4

# Fail when legal/License.txt, News.txt or legal/Authors.txt are no longer executable, so this can be dropped
test -x legal/License_for_SparkleShare.txt -a -x News.txt -a -x legal/Authors.txt
chmod a-x legal/*.txt News.txt

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
    --disable-appindicator
# check on update if parallel builds are supported; currently broken
make V=1 #%{?_smp_mflags} 

%install
%makeinstall
%if %{?with_translations}
%find_lang %{name} %{?no_lang_C}
%endif
%suse_update_desktop_file -G "Synchronization Tool" %{name} FileTransfer
%suse_update_desktop_file sparkleshare-invite-opener
%fdupes %{buildroot}%{_datadir}

# There is no real reason to install the ubuntu-themed icons, as we are not Ubuntu
find %{buildroot}%{_datadir}/icons/ -type d -name ubuntu* -maxdepth 1 -exec rm -r {} \;

%clean
rm -rf %{buildroot}

%post
%desktop_database_post
%icon_theme_cache_post
%icon_theme_cache_post gnome

%postun
%desktop_database_postun
%icon_theme_cache_postun
%icon_theme_cache_postun gnome

%files
%defattr(-,root,root)
%doc legal/* News.txt
%{_bindir}/sparkleshare
%{_datadir}/applications/sparkleshare.desktop
%{_datadir}/applications/sparkleshare-invite-opener.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%dir %{_datadir}/icons/gnome
%dir %{_datadir}/icons/gnome/*
%dir %{_datadir}/icons/gnome/*/*
%{_datadir}/icons/gnome/*/*/*
%{_datadir}/sparkleshare/
%{_libdir}/sparkleshare/

%if %{with_translations}
%files lang -f %{name}.lang
%endif

%changelog
* Fri Aug 12 2016 dimstar@opensuse.org
- Hack up build/m4/shamrock/mono.m4 to look for Mono 4.5
  assemblies (sed 4.0 => 4.5).
* Wed Apr  8 2015 dimstar@opensuse.org
- Update to version 1.4:
  + Check user's local bin folders for git binary.
  + Show a notification after trying to start the app multiple
    times.
  + Set default focus on password fields when setting up
    encryption.
  + Show disclosure triangly on Recent Changes window timestamps.
  + Fix some conflict resolution issues by merging instead of
    rebasing on the remote.
  + Fix crash when copying to clipboard on Windows.
  + Sync more quickly after the system wakes up from sleep.
  + Fix conflict resolution when renaming folders.
* Sat Oct  4 2014 dimstar@opensuse.org
- Update to version 1.3:
  + Port interface from GTK+2 to GTK+3, replace widget
    implementations with new APIs.
  + Use GTK+3 compatible bindings for libnotify, webkitgtk, and
    appindicator.
  + Many style usability and behaviour fixes in the setup dialog.
  + Fix annoying flicker when changing projects on the Recent
    Changes window.
  + Improved window scalability of the Recent Changes window and
    about dialog.
  + Remove menu item that toggles notifications (this can now be
    done in GNOME's system menu).
  + Refocus on existing SparkleShare instance when starting
    multiple times.
  + Include an appdata XML file for the GNOME Software application.
  + Show correct icon and application name on GNOME 3 and Ubuntu.
- Update BuildRequires for port to GTK3:
  + Drop pkgconfig(gtk-sharp-2.0), pkgconfig(notify-sharp) and
    pkgconfig(webkit-sharp-1.0)
  + Add pkgconfig(gtk-sharp-3.0), pkgconfig(notify-sharp-3.0) and
    pkgconfig(webkitgtk-sharp-3.0).
* Tue Oct  8 2013 dimstar@opensuse.org
- Update to version 1.2.0
  + Fixes to the invite feature, now works when SparkleShare isn't
    running yet.
  + Don't crash, but complain when FIPS is enabled on Windows.
  + Fix some interface logic in Add dialog.
  + Fix some inaccurate sync state messages in the status icon.
  + Fix conflict when running when TortoiseGit is installed.
  + Fix blank Add dialog on OS X Snow Leopard.
  + Fix crash when user cancels initial project download.
  + Fix Continue button not enabling when entering encryption
    password.
  + Fix Planio plugin name showing up as Gitorious on Linux.
  + Show download speed on initial project add.
- Add libtool BuildRequires and call to autogen.sh: needed, as the
  tarball comes from github and is not bootstrapped yet.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 1.1.0:
  + Fixed retina Mac support.
  + Don't sync files with names that are problematic on Windows.
  + Show Client ID (link code) in the status icon menu.
  + Don't show notifications for changes that you made yourself.
  + Use large message tray icon on GNOME 3.
  + Added a plugin for plan.io.
  + Work with host keys other than just RSA.
  + "%%20" and "_" in project names become spaces in folder names.
  + Stricter permissions on the SparkleShare folder on Unix
    systems.
  + Open folders in the event log by clicking project names.
  + Allow spaces in passwords.
  + Change invite scheme to sparkleshare://addProject/$URL.
  + Many other bug fixes and tweaks.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 1.0.0:
  + Rebrand 0.9.10 with some minor changes to 1.0.0.
- Changes from version 0.9.10:
  + Fix folders not opening from statusicon menu on Windows
  + Fix freeze on Mac when retrying a failed add a project attempt
  + Fix a freeze on Mac when updating the status icon when the menu
    is open
- Changes from version 0.9.9:
  + Add high resolution images for retina displays on macs
  + Put uncommonly used menu items in a submenu in the statusicon
  + Fix an issue connecting to encrypted projects
  + New tutorial slides
  + Detect more types of sync errors
  + Various small fixes and cleanups
- Changes from version 0.9.8:
  + Show both the cumulative upload and download speeds when
    multiple projects are syncing at the same time
  + Defer receiving changes when affected files are locked and show
    a warning in the statusicon (mostly affects Windows)
  + Fix an issue where changing the case of a file name that will
    be synced to Windows or Mac would result in a no longer
    syncable project
  + Add a "Try Again" action underneath every error reported in the
    statusicon to force a retry
  + Always sync to the default git branch even when it's not named
    "master" (e.g. "gh-pages")
  + Fix unicode characters displaying weirdly in the event log
- Changes from version 0.9.7:
  + Remove Growl and use native OS X notifications
  + Treat underscores in project names as spaces for the folder
    names
  + Allow periods "." in project names
  + Depend on git >= 1.7.12
  + Fix Mac unicode compatibility (could cause duplicate files or
    folders between different platforms)
* Wed Nov  7 2012 gber@opensuse.org
- Update to version 0.9.6:
  + Show link code and Copy button on last tutorial page
  + Fix crash when the SparkleShare folder is on an unmounted
    drive
  + Fix crash of the event log on Windows
  + Keep Continue button in the same place on each tutorial page
  + Remove dock icon badging on Mac now that Mountain Lion has
    a notification queue
  + Fix "Show all" link not working in event log
  + Fix wrong version number in the Windows about dialog
  + Fix some problems with encrypted projects
  + Fix .sparkleshare file not always being hidden on Windows
  + Fix "Open files" button when an encrypted project has been
    added
  + Fix a crash of the event log on Windows
  + Remove Nautilus extension
  + Restore previous revisions of files from the event log
  + Fix Mac file system watcher not always triggering
  + Add symbolic icon for GNOME 3
  + New Bitbucket and default user icon
  + For encrypted projects, use a different salt for each project
- Drop and obsolete nautilus-sparkleshare sunpackage, following
  upstreams removal of the nautilus extension.
- Drop python-nautilus-devel BuildRequires: it was only needed for
  the nautilus extension.
- Change license tag to GPL-3.0+, which is the license specified
  in the source files.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 0.9.3:
  + Fix endless loop when adding empty folders
  + Fix freeze when adding lots of files
  + Fix using hosts with a non-standard SSH port
  + Fix receiving of notification service message after the first
    one
  + New non-animating status icons
  + More descriptive error reporting in the status icon
  + Add link to debug log in the about dialog
  + Use port 443 on the notification service to work better in
    restricted networks
* Fri Sep 21 2012 nmo.marques@gmail.com
- Update to version 0.9.2:
  + fixes a crash that can happen after adding a new project as
    well ssh-agent sometimes not starting in Windows
  + parallel builds disabled in %%build; currently broken
- Changes from version 0.9.1:
  + use HTTPS to fetch gravatars
  +mWebsite links in the about dialog
  + Scalable custom folder icon in Nautilus 3.x
  + Default host user is now "storage" instead of "git"
  + Create crash reports in ~/SparkleShare when things go wrong
  + New Windows folder icons
  + Project folders can now be renamed in the file manager
  + Resizable event log on Mac
  + Fix some bugs in conflict resolution mechanis
- Changes from version 0.9.0:
  + Experimental client side encryption using OpenSSL's AES
  + Allow setting custom paths in config.xml
  + Ship host keys of default plugins and verify on project add
  + Don't touch the user's ~/.ssh/config to configure SSH
  + Make fetching remote project's history optional
  + Cached logs for faster event log loading/switching
  + Sort event log file entries by time
  + Change default notification service to use port 80
  + Show backend error message(s) when on failed project add
  + Update Growl framework to version 1.3.1: A separate Growl is no
    longer needed and ready for Mountain Lion's notifications
  + Monochrome appindicator icons on Ubuntu
  + For changes of the latest 0.8.x releases, see News.txt
- Do not package the Ubuntu icon themes
- Drop help-C.tar.bz2 source: there is currently no support for
  translations and/or help.
- Introduce with_translations defines:
  + Conditionally create a lang-package and call find_lang only
    when with_translations is set to 1. Sparkleshare since 0.9.0
    does not come with any translations after the large rewrite
  + If translations are not enabled, do not BuildRequire intltools
    and gnome-doc-utils-devel.
  + If with_translations is set to 0, Obsolete/prove the -lang
    package from the main package (to have a clean update logic).
* Mon Jan 23 2012 vuntz@opensuse.org
- Update to version 0.8.0:
  + Show syncing progress in the status icon
  + Hide dock icon on Mac until you open a window
  + Update dates in the event log after midnight
  + Don't let git compress already compressed files (.jpg .ogg
    .zip, etc.)
  + Limit git's memory usage
  + Ignore history of any added git/hg/bzr repositories, just add
    the files
  + Spin status icon on syncing changes made before startup
- Move to pkgconfig() BuildRequires:
  + Old ones: gtk-sharp2, notify-sharp, webkit-sharp.
  + New ones: glib-sharp-2.0, gtk-sharp-2.0, notify-sharp,
    webkit-sharp-1.0.
- Remove unneeded ndesk-dbus and ndesk-dbus-glib-devel
  BuildRequires, and ndesk-dbus Requires: they're not used anymore.
- Remove gtk-sharp2, notify-sharp, webkit-sharp Requires: they are
  automatically added the mono() way.
- Add help-C.tar.bz2 source containing help files, as those files
  are missing from the tarball again.
* Mon Jan  2 2012 dimstar@opensuse.org
- Update to version 0.6.0
  + Several fixes for annoying bugs and crashes
  + Fix freeze on quit on Mac
  + Show project and history size in the event log
- Remove help-C.tar.bz2 as the tarball now has the doc files.
* Fri Dec  2 2011 dimstar@opensuse.org
- Update to version 0.4.2:
  + Fix crash trying to add a project.
- Add libtool BuildRequires and rebootsrap during Build. The
  shipped tarball was not properly bootstrapped, as it fails
  entirely to install help files now.
- Change License tag to spdx identifiers
- Add code to remove x bit on AUTHORS file to silence lint
  warnings.
* Wed Nov 30 2011 dimstar@opensuse.org
- Update to version 0.4.1:
  + Bundle git with the Mac application
  + Warn about potential global gitignore files
  + Remove SmartIrc4Net
  + Build system fixes
  + Code cleanups.
- Add help-C.tar.bz2: The tarball has been created without the doc
  enabled and as a result, the help files are missing. Inject them
  during the build.
* Tue Nov 15 2011 dimstar@opensuse.org
- Update to version 0.4.0:
  + Support OS X Lion.
  + Revamped "Add Hosted Project..." dialog.
  + First run tutorial.
  + Clicking notifications opens the event log.
  + Support for organisation/host plugins.
  + Adding empty folders now works.
  + More useful error reporting.
  + Progress bar on the initial sync, and a button to cancel.
  + Replace IRC by a custom protocol as the default notification
    system.
  + Port plugin to nautilus 3.x.
  + Many many fixes for crashes and bugs.
* Fri Sep  2 2011 vuntz@opensuse.org
- Fix typo in GenericName we add to sparkleshare.desktop.
  Fix bnc#631745.
* Tue Jul 26 2011 vuntz@opensuse.org
- Update to version 0.2.5:
  + Reimplement notes to be less buggy and backend independent.
  + Polish about dialog and event log html.
  + Fix a bug where large collections of files weren't being synced
    when adding them at the same time.
  + The event log now collapses huge change sets and squashes
    events together by day when they are on the same day and in the
    same folder.
  + Add a controller per UI component to make the Windows version
    easier to implement.
* Fri Jul  1 2011 malcolmlewis@opensuse.org
- Update to version 0.2.4:
  + Fix crash when setting up with an empty Git repository.
- Changes from version 0.2.3:
  + Add the ability to add notes in the event logs.
  + Fix some quirks in the webkit view on Linux.
  + Redo gravatar fetching parts to be more efficient.
  + Remove headless feature.
  + Fix some small bugs and crashes.
  + Try to use existing SSH keypair.
  + Required git version is now 1.7.1 or later.
- Change git-core Requires to be >= 1.7.1.
* Mon Jun 27 2011 malcolmlewis@opensuse.org
- Update to version 0.2.2:
  + Fix crash on first run when ~/.ssh doesn't exist.
  + Sync algorithm tweaks.
  + New global event log.
  + Ubuntu integration with libappindicator.
  + Poll sometimes even when using the notification service.
- Updates from version 0.2.1
  + Fix bug where host names with a "-" in them weren't accepted.
  + Fix crash that happens when the user doesn't have their
    "Real Name" set in the OS and a race condition connecting to
    the announcements server.
- Update spec file Licence field from GPLv3 to GPL-3.0 to conform
  with spdx.org identifier.
* Tue Jun  7 2011 vuntz@opensuse.org
- Update to 0.2:
  + Added support for Growl to show notifications on Mac.
  + Removed the dependancy on GitSharp.
  + File rename detection support in the event logs.
  + Fixed all crashes reported in RC1 and improved sync algorithm.
  + Redid collision detection and conflict resolving (use a copy of
    each version).
  + Improved about dialogs with version checking.
  + Pluggable backend (experimental Mercurial support).
- Detect where the nautilus extension is installed by checking the
  nautilus-python pkg-config file, to make sure we build fine
  against all versions of openSUSE.
* Sun May  8 2011 vuntz@opensuse.org
- Update to 0.2-rc1:
  + Lot of fixes and optimisations across the backend
  + Less memory usage, less crashes
  + Instant notifications of new changes instead of polling
  + Refreshed event log HTML theme
  + Keeping logs in memory for faster reopening and loads more
    goodness
- Changes from 0.2-beta2:
  + Massive restructure of the code to an MVC-like model
  + Port the event logs to Webkit
- Add nant and webkit-sharp BuildRequires.
- Add webkit-sharp Requires.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call missing relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Sat Sep 25 2010 vuntz@opensuse.org
- Add gnome-doc-utils-devel BuildRequires to build the help.
* Mon Sep  6 2010 vuntz@opensuse.org
- Update to version 0.2-beta1:
  + Improve event logs:
  - make them prettier
  - add link for easy access to files
  - automatically refresh on new events
  + Nautilus plugin:
  - add "Copy Web Link" context menu item, to make sharing links
    easier
  + Misc bug fixes.
- Drop sparkleshare-fix-encoding.patch: fixed upstream.
* Sat Sep  4 2010 vuntz@opensuse.org
- Add sparkleshare-fix-encoding.patch to fix string encoding issues
  in the interface, because the encoding is defined wrong at build
  time.
* Thu Aug 26 2010 vuntz@opensuse.org
- Update to version 0.2-alpha2.
- Add python-nautilus-devel BuildRequires and python-nautilus
  Requires to build nautilus extension, which is split in a
  nautilus-sparkleshare subpackage.
- Remove monodevelop BuildRequires and replace mono-core
  BuildRequires with mono-devel.
- Change git Requires to git-core.
- Drop sparkleshare-desktop.patch and instead use
  %%suse_update_desktop_file to add GenericName and a category.
- Split lang package.
- Use fdupes.
- Clean up packaging a bit.
* Tue Aug 10 2010 awafaa@opensuse.org
- Update to new version 0.2.20100810
* Tue Aug  3 2010 prusnak@opensuse.org
- fix desktop file (desktop.patch)
- spec cleanup
* Tue Aug  3 2010 awafaa@opensuse.org
- New version 0.2.201000803
- Remove so_solid_moo's patches as they are now integrated upstream
* Wed Jul 28 2010 awafaa@opensuse.org
- Add fix-icon-path.diff & icon-resize.diff thanks to so_solid_moo
* Tue Jul 27 2010 awafaa@opensuse.org
- New version 0.1.20100727
* Mon Jun 28 2010 awafaa@opensuse.org
- New version 0.1.20100628
* Thu Jun 17 2010 awafaa@opensuse.org
- Add sparkleshare-build.patch & sparkleshare-bash-path.patch
* Thu Jun 17 2010 awafaa@opensuse.org
- Initial import for openSUSE version 0.1.20100617
